# Docker CLI that combine docker-compose and docker-machine for a full stack deployment

- Describe all your project stack in one file
- Manage and deploy in one or few command
- Compose file extensions with environment contexts and machines
- Combine services for extremely more readability
- Compatible with any docker-compose existing files
- Totaly Docker compatible, it just an overrider tool and a command manager
- Nginx emperor capability for manage multiple web hosted project
- Zero downtime deployment capability
- Lightweight and dependency-less